<?php namespace Elementor;

class ContactinfoWidget extends Widget_Base{
    public function get_name(){
        return "contact-info";
    }
    public function get_title(){
        return "Contact Info";
    }
    public function get_icon(){
        return "eicon-form-horizontal";
    }
    public function get_categories(){
        return ['cyarb-elements'];
    }

    protected function register_controls(){

    // Start Left Contact Controls
    $this-> start_controls_section(
        'contact_content',
        [
            'label'=>__('Contact Content', 'cyarb-toolkit'),
            'tab'=> Controls_Manager::TAB_CONTENT,
        ]
    );

    $this->add_control(
        'title',
        [
            'label' => esc_html__( 'Title', 'cyarb-toolkit' ),
            'type' => Controls_Manager::TEXT,
            'default' => esc_html__('Send Us A Message', 'cyarb-toolkit'),
        ]
    );

    $this->add_control(
        'title_tag',
        [
            'label' => esc_html__( 'Title Tag', 'cyarb-toolkit' ),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'h1'         => esc_html__( 'h1', 'cyarb-toolkit' ),
                'h2'         => esc_html__( 'h2', 'cyarb-toolkit' ),
                'h3'         => esc_html__( 'h3', 'cyarb-toolkit' ),
                'h4'         => esc_html__( 'h4', 'cyarb-toolkit' ),
                'h5'         => esc_html__( 'h5', 'cyarb-toolkit' ),
                'h6'         => esc_html__( 'h6', 'cyarb-toolkit' ),
            ],
            'default' => 'h2',
        ]
    );

    $this->add_control(
        'content', [
            'label'     => __( 'Content', 'cyarb-toolkit' ),
            'type'=>Controls_Manager:: WYSIWYG,
        ]
    );

    $this->add_control(
        'shortcode',
        [
            'label' => esc_html__( 'Contact Shortcode', 'cyarb-toolkit' ),
            'type' => Controls_Manager::TEXT,
        ]
    ); 
    $this-> end_controls_section();
    // End Contact Controls

    // Start Contact Style
    $this-> start_controls_section(
        'contact_style',
        [
            'label'=>__('Contact Section Style', 'cyarb-toolkit'),
            'tab'=> Controls_Manager::TAB_STYLE,
        ]
    );
    $this->add_control(
        'title_color',
        [
            'label' => esc_html__( 'Title Color', 'cyarb-toolkit' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .section-title h1, .section-title h2, .section-title h3, .section-title h4, .section-title h5, .section-title h6' => 'color: {{VALUE}}',
            ],
        ]
    );

    $this->add_group_control(
        Group_Control_Typography::get_type(),
        [
            'name' => 'title_typography',
            'label' => __( 'Title Typography', 'cyarb-toolkit' ),
            'selector' => '{{WRAPPER}} .section-title h1, .section-title h2, .section-title h3, .section-title h4, .section-title h5, .section-title h6',
        ]
    );

    $this->add_control(
        'desc_color',
        [
            'label' => esc_html__( 'Description Color', 'cyarb-toolkit' ),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .section-title p' => 'color: {{VALUE}}',
            ],
        ]
    );

    $this->add_group_control(
        Group_Control_Typography::get_type(),
        [
            'name' => 'desc_typography',
            'label' => __( 'Description Typography', 'cyarb-toolkit' ),
            'selector' => '{{WRAPPER}} .section-title p',
        ]
    );
    $this-> end_controls_section();
}
    // Register control section end here

    protected function render() 
    {
        $settings = $this->get_settings_for_display(); ?>

        <div class="contact-area pb-100">
            <div class="container">
                <div class="section-title">
                    <<?php echo esc_attr($settings['title_tag']);?>><?php echo esc_html( $settings['title'] ); ?></<?php echo esc_attr($settings['title_tag']);?>>
                    <?php echo wp_kses_post( $settings['content'] ); ?>
                </div>
                <div class="contact-form">

                    <?php $form = $settings['shortcode']; 
                    echo do_shortcode($form); ?>

                </div>
            </div>
        </div>
    <?php    
    }
}
Plugin::instance()->widgets_manager->register_widget_type( new ContactinfoWidget );